@@ -23,7 +23,7 @@ from xpander_sdk.modules.knowledge_bases.models.knowledge_bases import (
     KnowledgeBaseSearchResult,
 )
 from xpander_sdk.modules.tools_repository.models.mcp import MCPServerDetails
-from xpander_sdk.models.shared import LLMModelT, OutputFormat, XPanderSharedModel
+from xpander_sdk.models.shared import LLMModelT, OutputFormat, ThinkMode, XPanderSharedModel
 from xpander_sdk.models.user import User
 from xpander_sdk.modules.agents.models.agent import (
     AgentAccessScope,
@@ -382,7 +382,7 @@ class Agent(XPanderSharedModel):
         user_details: Optional[User] = None,
         agent_version: Optional[str] = None,
         tool_call_payload_extension: Optional[dict] = None,
-        source: Optional[str] = None,
+        source: Optional[str] = "sdk",
         worker_id: Optional[str] = None,
         run_locally: Optional[bool] = False,
         output_format: Optional[OutputFormat] = None,
@@ -393,6 +393,7 @@ class Agent(XPanderSharedModel):
         mcp_servers: Optional[List[MCPServerDetails]] = [],
         triggering_agent_id: Optional[str] = None,
         title: Optional[str] = None,
+        think_mode: Optional[ThinkMode] = ThinkMode.Default
     ) -> Task:
         """
         Asynchronously create a new task and link it to this agent.
@@ -404,7 +405,7 @@ class Agent(XPanderSharedModel):
             user_details (Optional[User]): User linked to this task context.
             agent_version (Optional[str]): Optional agent version to use.
             tool_call_payload_extension (Optional[dict]): Extend payload with additional information.
-            source (Optional[str]): Origin or source of the request.
+            source (Optional[str]): Origin or source of the request. default = "sdk".
             worker_id (Optional[str]): Worker identifier if applicable.
             run_locally (Optional[bool]): Indicates if task should run locally.
             output_format (Optional[OutputFormat]): Format for output response.
@@ -414,7 +415,8 @@ class Agent(XPanderSharedModel):
             expected_output (Optional[str]): Expected output of the execution.
             mcp_servers (Optional[List[MCPServerDetails]]): Optional list of mcp servers to use.
             triggering_agent_id (Optional[str]): Optional triggering agent id.
-        title (Optional[str]): Optional task title.
+            title (Optional[str]): Optional task title.
+            think_mode (Optional[ThinkMode]): Optional task think mode, defaults to "default".
 
         Returns:
             Task: Created Task object linked to this agent.
@@ -447,6 +449,7 @@ class Agent(XPanderSharedModel):
                     "mcp_servers": [server.model_dump() for server in mcp_servers],
                     "triggering_agent_id": triggering_agent_id,
                     "title": title,
+                    "think_mode": think_mode.value,
                 },
             )
             return Task(**created_task, configuration=self.configuration)
@@ -568,12 +571,15 @@ class Agent(XPanderSharedModel):
         except Exception as e:
             logger.warning(f"Failed to sync local tools - {str(e)}")
 
-    async def aget_db(self):
+    async def aget_db(self, async_db: Optional[bool] = True):
         """
         Asynchronously retrieve the db for this agent.
 
+        Args:
+            async_db (Optional[bool]): Should return async database client.
+        
         Returns:
-            AsyncPostgresDb: Initialized async db (Agno PG) for agent sessions.
+            AsyncPostgresDb|PostgresDb: Initialized (async?) db (Agno PG) for agent sessions.
 
         Raises:
             NotImplementedError: If the framework does not support storage.
@@ -589,7 +595,7 @@ class Agent(XPanderSharedModel):
             raise LookupError("Session storage is not enabled for this agent.")
 
         try:
-            from agno.db.postgres import AsyncPostgresDb
+            from agno.db.postgres import AsyncPostgresDb, PostgresDb
         except ImportError as e:
             raise ImportError(
                 "The 'agno' extras must be installed to use this db. "
@@ -603,10 +609,12 @@ class Agent(XPanderSharedModel):
             )
 
         schema = get_db_schema_name(agent_id=self.id)
+        
+        client_type = AsyncPostgresDb if async_db else PostgresDb
 
-        return AsyncPostgresDb(
+        return client_type(
             db_schema=schema,
-            db_url=connection_string.connection_uri.uri.replace("postgresql", "postgresql+psycopg_async"),
+            db_url=connection_string.connection_uri.uri.replace("postgresql", "postgresql+psycopg"+("_async" if async_db else "")),
         )
 
     def get_db(self) -> Any:
@@ -619,7 +627,7 @@ class Agent(XPanderSharedModel):
         Example:
             >>> db = agent.get_db()
         """
-        return run_sync(self.aget_db())
+        return run_sync(self.aget_db(async_db=False))
 
     @computed_field
     @property
@@ -816,7 +824,7 @@ class Agent(XPanderSharedModel):
         Example:
             >>> await agent.adelete_session(session_id="sess_456")
         """
-        db = await self.aget_db()
+        db = await self.aget_db(async_db=False)
         await asyncio.to_thread(db.delete_session, session_id=session_id)
     
     def delete_session(self, session_id: str):
