@@ -6,7 +6,7 @@ from typing import Any, Callable, Dict, List, Optional
 from loguru import logger
 
 from xpander_sdk import Configuration
-from xpander_sdk.models.shared import OutputFormat
+from xpander_sdk.models.shared import OutputFormat, ThinkMode
 from xpander_sdk.modules.agents.agents_module import Agents
 from xpander_sdk.modules.agents.models.agent import AgentGraphItemType
 from xpander_sdk.modules.agents.sub_modules.agent import Agent
@@ -19,6 +19,7 @@ from xpander_sdk.modules.tools_repository.sub_modules.tool import Tool
 from xpander_sdk.modules.tools_repository.utils.schemas import build_model_from_schema
 from agno.agent import Agent as AgnoAgent
 from agno.team import Team as AgnoTeam
+from agno.memory import MemoryManager
 from agno.guardrails import PIIDetectionGuardrail
 from agno.guardrails import PromptInjectionGuardrail
 from agno.guardrails import OpenAIModerationGuardrail
@@ -28,17 +29,19 @@ async def build_agent_args(
     task: Optional[Task] = None,
     override: Optional[Dict[str, Any]] = None,
     tools: Optional[List[Callable]] = None,
+    is_async: Optional[bool] = True
 ) -> Dict[str, Any]:
     model = _load_llm_model(agent=xpander_agent, override=override)
     args: Dict[str, Any] = {
         "id": xpander_agent.id,
+        "store_events": True
     }
 
     _configure_output(args=args, agent=xpander_agent, task=task)
     _configure_session_storage(args=args, agent=xpander_agent, task=task)
     _configure_user_memory(args=args, agent=xpander_agent, task=task)
     await _attach_async_dependencies(
-        args=args, agent=xpander_agent, task=task, model=model
+        args=args, agent=xpander_agent, task=task, model=model, is_async=is_async
     )
     _configure_knowledge_bases(args=args, agent=xpander_agent)
     _configure_additional_context(args=args, agent=xpander_agent, task=task)
@@ -47,9 +50,26 @@ async def build_agent_args(
 
     args["tools"] = await _resolve_agent_tools(agent=xpander_agent, task=task)
 
+    
     if tools and len(tools) != 0:
         args["tools"].extend(tools)
 
+    should_use_reasoning_tools = True if xpander_agent.agno_settings.reasoning_tools_enabled else False
+    if task and task.think_mode:
+        if task.think_mode == ThinkMode.Harder:
+            should_use_reasoning_tools = True
+
+    if not xpander_agent.is_a_team and should_use_reasoning_tools:
+        from agno.tools.reasoning import ReasoningTools
+        args["tools"].append(
+            ReasoningTools(
+                enable_think=True,
+                enable_analyze=True,
+                add_instructions=True,
+                add_few_shot=True
+            )
+        )
+        
     # team
     if xpander_agent.is_a_team:
         sub_agents = xpander_agent.graph.sub_agents
@@ -130,31 +150,48 @@ async def build_agent_args(
                 if xpander_agent.tools and len(xpander_agent.tools.list) != 0
                 else None
             )
-            if not matched_tool and task:  # agent / mcp tool
-                tool_instance = Tool(
-                    configuration=xpander_agent.configuration,
-                    id=function_name,
-                    name=function_name,
-                    method="GET",
-                    path=f"/tools/{function_name}",
-                    should_add_to_graph=False,
-                    is_local=True,
-                    is_synced=True,
-                    description=function_name,
-                )
-                await tool_instance.agraph_preflight_check(
-                    agent_id=xpander_agent.id,
-                    configuration=tool_instance.configuration,
-                    task_id=task.id,
-                )
         except Exception:
             pass
-
-        # Call the function
-        if asyncio.iscoroutinefunction(function_call):
-            result = await function_call(**arguments)
-        else:
-            result = function_call(**arguments)
+        
+        error = None
+        try:
+            # Call the function
+            if asyncio.iscoroutinefunction(function_call):
+                result = await function_call(**arguments)
+            else:
+                result = function_call(**arguments)
+            
+        except Exception as e:
+            error = str(e)
+            raise
+        finally:
+            try:
+                if not matched_tool and task:  # agent / mcp tool
+                    tool_instance = Tool(
+                        configuration=xpander_agent.configuration,
+                        id=function_name,
+                        name=function_name,
+                        method="GET",
+                        path=f"/tools/{function_name}",
+                        should_add_to_graph=False,
+                        is_local=True,
+                        is_synced=True,
+                        description=function_name,
+                    )
+                    parsed_result = None
+                    try:
+                        parsed_result = dict(result)
+                    except Exception:
+                        parsed_result = result
+                        
+                    await tool_instance.agraph_preflight_check(
+                        agent_id=xpander_agent.id,
+                        configuration=tool_instance.configuration,
+                        task_id=task.id,
+                        payload={"input": arguments, "output": error or parsed_result} if isinstance(arguments, dict) else None
+                    )
+            except Exception:
+                pass
 
         # Return the result
         return result
@@ -332,6 +369,7 @@ def _configure_user_memory(
     user = task.input.user if task and task.input and task.input.user else None
     if agent.agno_settings.user_memories and user and user.id:
         args["enable_user_memories"] = True
+        args["memory_manager"] = MemoryManager(delete_memories=True)
         args["enable_agentic_memory"] = True
 
     if user:  # add user details to the agent
@@ -339,12 +377,12 @@ def _configure_user_memory(
 
 
 async def _attach_async_dependencies(
-    args: Dict[str, Any], agent: Agent, task: Optional[Task], model: Any
+    args: Dict[str, Any], agent: Agent, task: Optional[Task], model: Any, is_async: Optional[bool] = True
 ) -> None:
     user = task.input.user if task and task.input and task.input.user else None
     should_use_users_memory = True if agent.agno_settings.user_memories and user and user.id else False
     if agent.agno_settings.session_storage or should_use_users_memory:
-        args["db"] = await agent.aget_db()
+        args["db"] = await agent.aget_db(async_db=is_async)
 
 def _configure_knowledge_bases(args: Dict[str, Any], agent: Agent) -> None:
     if agent.knowledge_bases:
@@ -423,10 +461,10 @@ async def _resolve_agent_tools(agent: Agent, task: Optional[Task] = None) -> Lis
     # Import MCP only if mcp_servers is present
     from agno.tools.mcp import (
         MCPTools,
-        StdioServerParameters,
         SSEClientParams,
         StreamableHTTPClientParams,
     )
+    from mcp import StdioServerParameters
 
     mcp_tools: List[MCPTools] = []
     is_xpander_cloud = getenv("IS_XPANDER_CLOUD", "false") == "true"
