@@ -9,6 +9,7 @@ async def dispatch_get_args(
     task: Optional[Task] = None,
     override: Optional[Dict[str, Any]] = None,
     tools: Optional[List[Callable]] = None,
+    is_async: Optional[bool] = True
 ) -> Dict[str, Any]:
     """
     Dispatch to the correct framework-specific argument resolver.
@@ -18,6 +19,7 @@ async def dispatch_get_args(
         task (Optional[Task]): Optional runtime task.
         override (Optional[Dict[str, Any]]): Dict of override values.
         tools (Optional[List[Callable]]): Optional additional tools to be added to the agent arguments.
+        is_async (Optional[bool]): Is in Async Context?.
 
     Returns:
         Dict[str, Any]: Arguments for instantiating the framework agent.
@@ -25,7 +27,7 @@ async def dispatch_get_args(
     match agent.framework:
         case Framework.Agno:
             from .agno import build_agent_args
-            return await build_agent_args(xpander_agent=agent, task=task, override=override, tools=tools)
+            return await build_agent_args(xpander_agent=agent, task=task, override=override, tools=tools, is_async=is_async)
         # case Framework.Langchain: # PLACEHOLDER
         #     from .langchain import build_agent_args
         #     return await build_agent_args(xpander_agent=agent, task=task, override=override)
