@@ -10,6 +10,7 @@ class MCPServerType(str, Enum):
     
 class MCPServerAuthType(str, Enum):
     APIKey = "api_key"
+    OAuth2 = "oauth2"
     CustomHeaders = "custom_headers"
     _None = "none"
 
@@ -26,6 +27,8 @@ class MCPServerDetails(BaseModel):
     transport: Optional[MCPServerTransport] = MCPServerTransport.HTTP_Transport
     auth_type: Optional[MCPServerAuthType] = MCPServerAuthType._None
     api_key: Optional[str] = None
+    client_id: Optional[str] = None
+    client_secret: Optional[str] = None
     headers: Optional[Dict] = {}
     env_vars: Optional[Dict] = {}
     allowed_tools: Optional[List[str]] = []
\ No newline at end of file
